@@ -1,5 +1,5 @@
 use crate::utils::*;
-use crate::markdown::inline::decoration::render_italic;
+use crate::markdown::inline::decoration::render_bold_and_italic;
 use crate::consts::*;
 
 
@@ -50,7 +50,7 @@ pub fn render_link(content: &Vec<u16>) -> Vec<u16> {
         curr_index += 1;
     }
 
-    render_italic(&result)
+    render_bold_and_italic(&result)
 }
 
 
