@@ -62,7 +62,7 @@ pub fn translate_to_latex(content: &Vec<u16>) -> Vec<u16> {
     let mut result = Vec::with_capacity(content.len());
     let mut tmp = vec![];
     let mut index = 0;
-    let mut content = escape_angle_brackets(content);
+    let mut content = escape_special_characters(content);
     content.push(U16_SPACE);  // so that it handles the last word
 
     while index < content.len() {
@@ -111,6 +111,12 @@ pub fn translate_to_latex(content: &Vec<u16>) -> Vec<u16> {
                         }
 
                         else {
+                            let argument = if tmp == into_v16("text") {
+                                arguments[0].clone()
+                            } else {
+                                translate_to_latex(&arguments[0])
+                            };
+
                             let func_name = if tmp == into_v16("sup") {
                                 vec![U16_CARET]
                             }
@@ -126,8 +132,6 @@ pub fn translate_to_latex(content: &Vec<u16>) -> Vec<u16> {
                                 ].concat()
                             };
 
-                            let argument = translate_to_latex(&arguments[0]);
-
                             result.push(vec![
                                 func_name,
                                 vec![U16_LEFT_CURLY_BRACE],
@@ -281,7 +285,7 @@ fn get_arguments(content: &Vec<u16>, index: usize, mut current_args: Vec<Vec<u16
 }
 
 
-fn escape_angle_brackets(content: &Vec<u16>) -> Vec<u16> {
+fn escape_special_characters(content: &Vec<u16>) -> Vec<u16> {
 
     let content = undo_html_escapes(content);
     let mut result = Vec::with_capacity(content.len() + content.len() / 6);
@@ -302,6 +306,31 @@ fn escape_angle_brackets(content: &Vec<u16>) -> Vec<u16> {
             result.push(U16_SPACE);
         }
 
+        else if *c == U16_ASTERISK {
+            result.push(BACKSLASH_ESCAPE_MARKER);
+            result.push(u16::MAX - U16_ASTERISK);
+        }
+
+        else if *c == U16_TILDE {
+            result.push(BACKSLASH_ESCAPE_MARKER);
+            result.push(u16::MAX - U16_TILDE);
+        }
+
+        else if *c == U16_LEFT_SQUARE_BRACKET {
+            result.push(BACKSLASH_ESCAPE_MARKER);
+            result.push(u16::MAX - U16_LEFT_SQUARE_BRACKET);
+        }
+
+        else if *c == U16_RIGHT_SQUARE_BRACKET {
+            result.push(BACKSLASH_ESCAPE_MARKER);
+            result.push(u16::MAX - U16_RIGHT_SQUARE_BRACKET);
+        }
+
+        else if *c == U16_CARET {
+            result.push(BACKSLASH_ESCAPE_MARKER);
+            result.push(u16::MAX - U16_CARET);
+        }
+
         else {
             result.push(*c);
         }
@@ -403,4 +432,23 @@ mod tests {
         assert_eq!(rendered, "\\sum\\limits _{n=1}^{\\infty } \\frac{1}{n ^{2}}  \\lt   10".to_string());
     }
 
+    #[test]
+    fn math_test7() {
+        let orig = crate::utils::into_v16("text{delta} delta");
+        let rendered = String::from_utf16_lossy(&crate::markdown::math::translate_to_latex(&orig));
+
+        assert_eq!(rendered, "\\text{delta} \\delta ".to_string());
+    }
+
+    #[test]
+    fn math_test8() {
+        let orig = "[[math]] text{when} x sup{*} (t) = x(t), space X(f) = X sup{*}(-f) [[/math]]".to_string();
+        let rendered = "<p>\\( \\text{when} x ^{&#42;} (t) = x(t), \\space  X(f) = X ^{&#42;}(-f) \\)</p>";
+
+        assert_eq!(
+            rendered.trim_end_matches('\n'),
+            crate::markdown::render(&orig).unwrap().trim_end_matches('\n')
+        );
+    }
+
 }
\ No newline at end of file
